#ifndef LEVY_INFER_H
#define LEVY_INFER_H



#include "tnt_array1d.h"
#include "tnt_array1d_utils.h"
#include "moreArray1dUtils.h"
#include <S.h>

using TNT::Array1D;


class LevyInfer{
 private:
  char *DatFL_, *DatVL_;
  double dist_;

  /**************************************************************************
   **  Get the value of the posterior surface at a vector of
   **  locations, given by their coordinates, for the sample with index sampNum.
   **/  
  Array1D<double> sampSurf( const Array1D<double> &xlocs, 
			    const Array1D<double> &ylocs, 
			    int sampNum);

  /**************************************************************************
   **  Get the height of a kernel centered at (x,y), with height=
   **  height, at the specified locations.
   **/  
  Array1D<double> kernelHeight(
    const Array1D<double> &xlocs, const Array1D<double> &ylocs,
    double x, double y, double height );
  
 public:
  LevyInfer( char *DatFL, char *DatVL,
	    double dist );

  ~LevyInfer(){};

  /**************************************************************************
   **  Get the value of the posterior surface at a vector of
   **  locations, given by their coordinates. If sampNum < 0 then the
   **  mean of the surface over the samples is returned, and otherwise
   **  the surface is evaluated for the sample with index sampNum.
   **/  
  Array1D<double> meanVals( const Array1D<double> &xlocs, 
			    const Array1D<double> &ylocs, 
			    int sampNum = -1 );

  /**************************************************************************
   **  Get the standard deviation of the posterior surface at a vector of
   **  locations, given by their coordinates. 
   **/  
  Array1D<double> stdevSurf( const Array1D<double> &xlocs, 
			     const Array1D<double> &ylocs );

  /**************************************************************************
   **  Get the percent of the posterior surface samples that is above
   **  a particular threshold, at a vector of locations given by their
   **  coordinates.
   **/  
  Array1D<double> percentAbove( const Array1D<double> &xlocs, 
				const Array1D<double> &ylocs, double cutoff );

  /**************************************************************************
   **  Get a quantile of the posterior surface at a vector of
   **  locations, given by their coordinates. Not yet implemented.
   **/  
  Array1D<double> quantileSurf( const Array1D<double> &xlocs, 
				const Array1D<double> &ylocs, 
				double quantile ) 
    { MESSAGE "Not yet implemented" ERROR; return(Array1D<double>()); };

  /**************************************************************************
   **  Get the sums of the jump heights for each iteration of the MCMC.
   **/  
  Array1D<double> zsums();

  /**************************************************************************
   **  Get the lrf for sample number sampNum
   **/  
  void getLrfSamp( int sampNum, Array1D<double> &xlocs, 
		   Array1D<double> &ylocs,
		   Array1D<double> &heights );

};

#endif
