// Compiled C subroutine to run the MCMC


#include "S.h"
#include "LevyMCMC.h"


extern "C"{

void MCMC(
     double *datX,   double *datY,   // The data (x, y, z for each of datLen samples, where (x,y) is the location
     double *datZ,   long *datLen,   // and z is the measurement)
     char **OutFL, char **OutVL,      // The names of the fixed-length and variable-length files to be written
     double *xlim,     double *ylim,  // The bounding region within which to fit the surface.  xlim and ylim should 
                                      //be length-2 vectors
     long *ItnMax,     long *ItnBrn,  // ItnMax is the number of total iterations after burnin, while ItnBrn is 
                                      // the length of the burnin
     long *JmpMax,     long *TimMax,  // JmpMax is the max number of atoms in the fit Poisson process.  TimMax 
                                      // is the maximum length of 
                                      // time to sample, in seconds.
     long *SavMax,     double *pX,    // SavMax is the maximum number of saved iterations.  The resulting thinning 
                                      // is approximately 
                                      // ItnMax / SavMax.  pX is a vector of the probabilities of proposing a move 
                                      // for each of the parameters:
                                      //     - prec: outcome (measurement) precision, conditional on a fixed z-surface
                                      //     - beta: the regression coefficients (not currently supported--should be zero)
                                      //     - birth: add a new atom
                                      //     - move: change the location and height of one of the existing atoms
                                      //     - remove: remove one of the atoms
     double *dX,       double *apre,  // dX is the step size for the proposal for each of the above move types.  apre and rpre
     double *rpre,     double *dist,  // are the parameters of the Gamma prior distribution for the outcome (measurement) precision.
     double *agam,     double *rgam,  // dist is the standard deviation of the independent bivariate normal kernels of which the surface
                                      // is composed.  agam and rgam are the parameters of the Levy process prior for the spatial 
                                      // surface.
     double *frac,                    // frac is the fraction of the mass to be truncated (this controls the value of epsilon)
     long *printStats)                // Whether or not to print summary statistics regarding the Markov chain 
                                      // acceptance rates etc.
{

  #ifdef DEBUG1
    printf("xlim = %f, %f, dist = %f \n", xlim[0], xlim[1], (*dist));
  #endif
  LevyMCMC *mcmc = new LevyMCMC(datX, datY, datZ, (int) (*datLen), 
				(*OutFL), (*OutVL), 
				xlim, ylim, (int) (*ItnMax), (int) (*ItnBrn), 
				(int) (*JmpMax), (int) (*TimMax), 
				(int) (*SavMax), pX, dX, (double) (*apre), 
				(double) (*rpre),
				(double) (*dist), (double) (*agam), 
				(double) (*rgam), (double) (*frac), (bool) (*printStats) );

  mcmc->doMCMC();

  delete(mcmc);
  return;
}
          
}


